# TypeGenieAPIClient
Python API client to access TypeGenie API. 

# Documentation
Check out detailed API documentation at [http://api.typegenie.net](http://api.typegenie.net)

## Installation
Run the following to install:

`pip install typegenie`
